@@ -33,17 +33,16 @@ class Domoticz(IPlugin):
 #
 	def switchlight(self, jsonInput):
 		bodies = ""
-		if jsonInput['outcome']['entities']['location']['body'] :
-			location = jsonInput['outcome']['entities']['location']['body']
-		else:
-			bodies = "pas de lieu"
-			location= "VIDE"
-
-		if jsonInput['outcome']['entities']['on_off']['value'] :
-			on_off = jsonInput['outcome']['entities']['on_off']['value']
-		else:
-			bodies = "pas de on/off"
-			on_off = "VIDE"
+#		if jsonInput['outcome']['entities']['location']['body'] :
+#			location = jsonInput['outcome']['entities']['location']['body']
+#		else:
+#			bodies = "pas de lieu"
+#			location= "VIDE"
+#		if jsonInput['outcome']['entities']['on_off']['value'] :
+#			on_off = jsonInput['outcome']['entities']['on_off']['value']
+#		else:
+#			bodies = "pas de on/off"
+#			on_off = "VIDE"
 		idex= location + "_" + on_off
 		log.msg("index :  %s" % (idex))		
 		for rs in self.configuration_plugin['param_dz']:
